@@ -20,7 +20,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 	 * @param {type} recordId
 	 * @returns {undefined}
 	 */
-	previewFile: function (e, recordId,attachmentId) {
+	previewFile: function (e, recordId, attachmentId) {
 		e.stopPropagation();
 		if (recordId) {
 			var params = {
@@ -29,9 +29,8 @@ Vtiger.Class('Vtiger_Index_Js', {
 				record: recordId,
 				attachmentid: attachmentId
 			};
-			app.request.post({data:params}).then(function(err, res){
+			app.request.post({data: params}).then(function (err, res) {
 				app.helper.showModal(res);
-				jQuery('.filePreview .preview-area').height(jQuery(window).height()-143);
 			});
 		}
 	},
@@ -57,6 +56,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 			var frameElement = jQuery("#emailPreviewIframe")[0].contentWindow.document;
 			frameElement.open();
 			frameElement.close();
+			descriptionContent = app.helper.purifyContent(descriptionContent);
 			jQuery('#emailPreviewIframe').contents().find('html').html(descriptionContent);
 			jQuery("#emailPreviewIframe").height(jQuery('#emailPreviewIframe').contents().find('html').height());
 			jQuery('#emailPreviewIframe').contents().find('html').find('a').on('click', function(e) {
@@ -95,7 +95,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 						if(prefsNeedToUpdate && length > 1) {
 							app.helper.hideProgress();
 							app.helper.showModal(data);
-							emailEditInstance.registerEmailFieldSelectionEvent();
+							emailEditInstance.registerEmailFieldSelectionEvent(cb);
 							return true;
 						}
 
@@ -104,14 +104,14 @@ Vtiger.Class('Vtiger_Index_Js', {
 							if(saveRecipientPref) {
 								var params = form.serializeFormData();
 								emailEditInstance.showComposeEmailForm(params).then(function(response) {
-								jQuery(document).on('shown.bs.modal', function() {
-									if (typeof cb === 'function') cb(response);
+									jQuery(document).on('shown.bs.modal', function() {
+										if (typeof cb === 'function') cb(response);
+									});
 								});
-							});
 							}else {
 								app.helper.hideProgress();
 								app.helper.showModal(data);
-								emailEditInstance.registerEmailFieldSelectionEvent();
+								emailEditInstance.registerEmailFieldSelectionEvent(cb);
 							}
 						}else{
 							emailFields.attr('checked','checked');
@@ -126,6 +126,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 				});
 			} else {
 				app.helper.showAlertBox({'message':app.vtranslate('JS_EMAIL_SERVER_CONFIGURATION')});
+				app.helper.hideProgress();
 			}
 		});
 	},
@@ -271,22 +272,22 @@ Vtiger.Class('Vtiger_Index_Js', {
 	showReminderPopup : function(record) {
 		var notifyParams = {
 			'title' : record.activitytype + ' - ' +
-					'<a target="_blank" href="index.php?module=Calendar&view=Detail&record='+record.id+'">'+record.subject+'</a>&nbsp;&nbsp;'+
-					'<i id="reminder-postpone-'+record.id+'" title="'+app.vtranslate('JS_POSTPONE')+'" class="cursorPointer fa fa-clock-o"></i>',
+				'<a target="_blank" href="index.php?module=Calendar&view=Detail&record='+record.id+'">'+record.subject+'</a>&nbsp;&nbsp;'+
+				'<i id="reminder-postpone-'+record.id+'" title="'+app.vtranslate('JS_POSTPONE')+'" class="cursorPointer fa fa-clock-o"></i>',
 			'message' : '<div class="col-sm-12">'+
-							'<div class="row">'+
-								'<div class="col-sm-12 font13px">'+
-									app.vtranslate('JS_START_DATE_TIME') + ' : ' + record.date_start+
-								'</div>'+
-								'<div class="col-sm-12 font13px">'+
-									app.vtranslate('JS_END_DATE_TIME') + ' : ' + record.due_date+
-								'</div>'+
-							'</div>'+
-						'</div>'
+				'<div class="row">'+
+				'<div class="col-sm-12 font13px">'+
+				app.vtranslate('JS_START_DATE_TIME') + ' : ' + record.date_start+
+				'</div>'+
+				'<div class="col-sm-12 font13px">'+
+				app.vtranslate('JS_END_DATE_TIME') + ' : ' + record.due_date+
+				'</div>'+
+				'</div>'+
+				'</div>'
 		};
 		var settings = {
-			'element' : 'body', 
-			'type' : 'danger', 
+			'element' : 'body',
+			'type' : 'danger',
 			'delay' : 0
 		};
 
@@ -306,7 +307,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 	}
 
 }, {
-	 _SearchIntiatedEventName : 'VT_SEARCH_INTIATED',
+	_SearchIntiatedEventName : 'VT_SEARCH_INTIATED',
 	usernames : [],
 	userList : {},
 	autoFillElement : false,
@@ -332,10 +333,10 @@ Vtiger.Class('Vtiger_Index_Js', {
 			app.request.post({data: params});
 			if(jQuery('.sidebar-essentials').hasClass('hide')) {
 				jQuery('.essentials-toggle-marker').removeClass('fa-chevron-left')
-						.addClass('fa-chevron-right');
+					.addClass('fa-chevron-right');
 			} else {
 				jQuery('.essentials-toggle-marker').removeClass('fa-chevron-right')
-						.addClass('fa-chevron-left');
+					.addClass('fa-chevron-left');
 			}
 			app.event.trigger("Vtiger.Post.MenuToggle");
 		});
@@ -375,6 +376,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 		this.registerHoverEventOnAttachment();
 		//this.addBodyScroll();
 		this.modulesMenuScrollbar();
+		this.modulesMenuClearIconTitle();
 		Vtiger_Index_Js.registerActivityReminder();
 		//reference preview event registeration
 		this.registerReferencePreviewEvent();
@@ -385,23 +387,23 @@ Vtiger.Class('Vtiger_Index_Js', {
 
 	addBodyScroll: function () {
 		app.helper.showVerticalScroll(
-				$("body"),
-				{
-					setHeight: $(window).height() - 92,
-					theme: "inset-dark",
-					alwaysShowScrollbar: 2,
-					autoExpandScrollbar: true,
-					live: "on",
-					setTop: 0,
-					scrollInertia: 70,
-					mouseWheel:{ preventDefault: true }
+			$("body"),
+			{
+				setHeight: $(window).height() - 92,
+				theme: "inset-dark",
+				alwaysShowScrollbar: 2,
+				autoExpandScrollbar: true,
+				live: "on",
+				setTop: 0,
+				scrollInertia: 70,
+				mouseWheel:{ preventDefault: true }
 
-				}
+			}
 		);
 	},
 	registerEventForTaskManagement : function(){
 		var globalNav = jQuery('.global-nav');
-		globalNav.on("click",".taskManagement",function(e){
+		globalNav.find(".taskManagement").on("click",function(e){
 			if(jQuery("#taskManagementContainer").length > 0){
 				app.helper.hidePageOverlay();
 				return false;
@@ -492,9 +494,9 @@ Vtiger.Class('Vtiger_Index_Js', {
 					//fix for Refresh list view after Quick create
 					var parentModule=app.getModuleName();
 					var viewname=app.view();
-					if((quickCreateModuleName == parentModule) && (viewname=="List")){
-							var listinstance = app.controller();
-							listinstance.loadListViewRecords(); 
+					if(((quickCreateModuleName == parentModule) || (quickCreateModuleName == 'Events' && parentModule == 'Calendar')) && (viewname=="List")){
+						var listinstance = app.controller();
+						listinstance.loadListViewRecords();
 					}
 				};
 			}
@@ -510,12 +512,17 @@ Vtiger.Class('Vtiger_Index_Js', {
 					},
 					backdrop : 'static',
 					keyboard : false
-					}
+				}
 
 				app.helper.showModal(data, callbackparams);
 				var form = jQuery('form[name="QuickCreate"]');
 				var moduleName = form.find('[name="module"]').val();
-				app.helper.showVerticalScroll(jQuery('form[name="QuickCreate"] .modal-body'), {'autoHideScrollbar': true});
+				var Options= {
+					scrollInertia: 200,
+					autoHideScrollbar: true,
+					setHeight:(jQuery(window).height() - jQuery('form[name="QuickCreate"] .modal-body').find('.modal-header').height() - jQuery('form[name="QuickCreate"] .modal-body').find('.modal-footer').height()- 135),
+				}
+				app.helper.showVerticalScroll(jQuery('form[name="QuickCreate"] .modal-body'), Options);
 
 				var targetInstance = thisInstance;
 				var moduleInstance = Vtiger_Edit_Js.getInstanceByModuleName(moduleName);
@@ -659,7 +666,10 @@ Vtiger.Class('Vtiger_Index_Js', {
 			appMenu.appendTo('#page');
 			appMenu.css({
 				'top' : appNav.offset().top + appNav.height(),
-				'left' : 0
+				'left' : 0,
+				//Fix for Responsive layout Sub Menu in mobile devices
+				'width' : '50%',
+				'max-width' : '230px'
 			});
 			if(typeof type === 'undefined') {
 				type = appMenu.is(':hidden') ? 'show' : 'hide';
@@ -692,11 +702,14 @@ Vtiger.Class('Vtiger_Index_Js', {
 			var dropdownContainer = jQuery(e.currentTarget);
 			jQuery('.dropdown').removeClass('open');
 			if(dropdownContainer.length) {
+				//Fix for Responsive layout Sub Menu in mobile devices
+				var appModulesDropdown = dropdownContainer.find('.app-modules-dropdown');
 				if(dropdownContainer.hasClass('dropdown-compact')) {
-					dropdownContainer.find('.app-modules-dropdown').css('top', dropdownContainer.position().top - 8);
+					appModulesDropdown.css('top', dropdownContainer.position().top - 8);
 				} else {
-					dropdownContainer.find('.app-modules-dropdown').css('top', '');
+					appModulesDropdown.css('top', '');
 				}
+				appModulesDropdown.css('left', appModulesDropdown.parent().width() - 8);
 				dropdownContainer.addClass('open').find('.app-item').addClass('active-app-item');
 			}
 		}, function(e) {
@@ -710,10 +723,13 @@ Vtiger.Class('Vtiger_Index_Js', {
 
 		});
 
-		jQuery('.app-item').on('click', function() {
+		//Fix for Responsive layout Sub Menu in mobile devices
+		jQuery('.app-item').on('click', function(e) {
 			var url = jQuery(this).data('defaultUrl');
-			if(url) {
+			if(url && url!=='#') {
 				window.location.href = url;
+			} else {
+				e.stopPropagation();
 			}
 		});
 
@@ -797,15 +813,15 @@ Vtiger.Class('Vtiger_Index_Js', {
 						var reponseDataList = new Array();
 						var serverDataFormat = data;
 						if(serverDataFormat.length <= 0) {
-								jQuery(inputElement).val('');
-								serverDataFormat = new Array({
-										'label' : 'No Results Found',
-										'type'	: 'no results'
-								});
+							jQuery(inputElement).val('');
+							serverDataFormat = new Array({
+								'label' : 'No Results Found',
+								'type'	: 'no results'
+							});
 						}
 						for(var id in serverDataFormat){
-								var responseData = serverDataFormat[id];
-								reponseDataList.push(responseData);
+							var responseData = serverDataFormat[id];
+							reponseDataList.push(responseData);
 						}
 						response(reponseDataList);
 					});
@@ -822,7 +838,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 				var selectedItemData = ui.item;
 				//To stop selection if no results is selected
 				if(typeof selectedItemData.type != 'undefined' && selectedItemData.type=="no results"){
-						return false;
+					return false;
 				}
 				var element = jQuery(this);
 				var parent = element.closest('td');
@@ -902,14 +918,14 @@ Vtiger.Class('Vtiger_Index_Js', {
 			var element = jQuery(e.currentTarget);
 			var closestTD = thisInstance.getParentElement(element).next();
 			var popupReferenceModule = element.val();
-			var referenceModuleElement = jQuery('input[name="popupReferenceModule"]', closestTD).length ? 
-			jQuery('input[name="popupReferenceModule"]', closestTD) : jQuery('input.popupReferenceModule', closestTD);
+			var referenceModuleElement = jQuery('input[name="popupReferenceModule"]', closestTD).length ?
+				jQuery('input[name="popupReferenceModule"]', closestTD) : jQuery('input.popupReferenceModule', closestTD);
 			var prevSelectedReferenceModule = referenceModuleElement.val();
 			referenceModuleElement.val(popupReferenceModule);
 
 			//If Reference module is changed then we should clear the previous value
 			if(prevSelectedReferenceModule != popupReferenceModule) {
-					closestTD.find('.clearReferenceSelection').trigger('click');
+				closestTD.find('.clearReferenceSelection').trigger('click');
 			}
 		});
 	},
@@ -926,7 +942,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 
 		var isMultiple = false;
 		if(params.multi_select) {
-				isMultiple = true;
+			isMultiple = true;
 		}
 
 		var sourceFieldElement = jQuery('input[class="sourceField"]',parentElem);
@@ -935,7 +951,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 		sourceFieldElement.trigger(prePopupOpenEvent);
 
 		if(prePopupOpenEvent.isDefaultPrevented()) {
-				return ;
+			return ;
 		}
 		var popupInstance = Vtiger_Popup_Js.getInstance();
 
@@ -953,7 +969,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 //						referenceModule = value.module;
 //					}
 //					if(parentElem.find('[name="popupReferenceModule"]').val() != referenceModule) continue;
-//					
+//
 					var data = {
 						'name' : value.name,
 						'id' : key
@@ -1007,40 +1023,40 @@ Vtiger.Class('Vtiger_Index_Js', {
 	 * @returns {undefined}
 	 */
 	registerFileChangeEvent: function () {
-		 var thisInstance = this;
-					var container = jQuery('body');
-			Vtiger_Index_Js.files = '';
-			container.on('change', 'input[name="filename[]"],input[name="imagename[]"]', function(e){
-				if(e.target.type == "text") return false;
+		var thisInstance = this;
+		var container = jQuery('body');
+		Vtiger_Index_Js.files = '';
+		container.on('change', 'input[name="filename[]"],input[name="imagename[]"]', function(e){
+			if(e.target.type == "text") return false;
 
-				var files_uploaded=[];
-				var fileSize = 0;
-				jQuery.each(e.target.files,function(key,element){
-					files_uploaded[key] = element;
-					fileSize += Number(element['size']);
-				});
+			var files_uploaded=[];
+			var fileSize = 0;
+			jQuery.each(e.target.files,function(key,element){
+				files_uploaded[key] = element;
+				fileSize += Number(element['size']);
+			});
 
 
-				Vtiger_Index_Js.files = files_uploaded;
-				var element = container.find('input[name="filename[]"],input[name="imagename[]"]');
-				//ignore all other types than file 
-				if(element.attr('type') != 'file'){
-						return ;
-				}
-				var uploadFileSizeHolder = element.closest('.fileUploadContainer').find('.uploadedFileSize');
-				var maxFileSize = thisInstance.getMaxiumFileUploadingSize(container);
-				if(fileSize > maxFileSize) {
-					alert(app.vtranslate('JS_EXCEEDS_MAX_UPLOAD_SIZE'));
-					var removeFileLinks = jQuery('.MultiFile-remove');
-					jQuery(removeFileLinks[removeFileLinks.length - 1]).click();
+			Vtiger_Index_Js.files = files_uploaded;
+			var element = container.find('input[name="filename[]"],input[name="imagename[]"]');
+			//ignore all other types than file
+			if(element.attr('type') != 'file'){
+				return ;
+			}
+			var uploadFileSizeHolder = element.closest('.fileUploadContainer').find('.uploadedFileSize');
+			var maxFileSize = thisInstance.getMaxiumFileUploadingSize(container);
+			if(fileSize > maxFileSize) {
+				alert(app.vtranslate('JS_EXCEEDS_MAX_UPLOAD_SIZE'));
+				var removeFileLinks = jQuery('.MultiFile-remove');
+				jQuery(removeFileLinks[removeFileLinks.length - 1]).click();
+			} else {
+				if(container.length > 1){
+					jQuery('div.fieldsContainer').find('form#I_form').find('input[name="filename"]').css('width','80px');
+					jQuery('div.fieldsContainer').find('form#W_form').find('input[name="filename"]').css('width','80px');
 				} else {
-					if(container.length > 1){
-						jQuery('div.fieldsContainer').find('form#I_form').find('input[name="filename"]').css('width','80px');
-						jQuery('div.fieldsContainer').find('form#W_form').find('input[name="filename"]').css('width','80px');
-					} else {
-						container.find('input[name="filename[]"]').css('width','80px');
-					}
+					container.find('input[name="filename[]"]').css('width','80px');
 				}
+			}
 		});
 	},
 
@@ -1081,18 +1097,18 @@ Vtiger.Class('Vtiger_Index_Js', {
 		var sourceModule = app.getModuleName();
 		var editTaskContainer = jQuery('[name="editTask"]');
 		if(editTaskContainer.length > 0){
-				sourceModule = editTaskContainer.find('#sourceModule').val();
+			sourceModule = editTaskContainer.find('#sourceModule').val();
 		}
 		var quickCreateConatiner = jQuery('[name="QuickCreate"]');
 		if(quickCreateConatiner.length!=0){
-				sourceModule = quickCreateConatiner.find('input[name="module"]').val();
+			sourceModule = quickCreateConatiner.find('input[name="module"]').val();
 		}
 		var searchResultContainer = jQuery('#searchResults-container');
 		if(searchResultContainer.length) {
 			sourceModule = jQuery('select#searchModuleList').val();
 		}
-		var popupReferenceModuleElement = jQuery('input[name="popupReferenceModule"]',container).length ? 
-		jQuery('input[name="popupReferenceModule"]',container) : jQuery('input.popupReferenceModule',container);
+		var popupReferenceModuleElement = jQuery('input[name="popupReferenceModule"]',container).length ?
+			jQuery('input[name="popupReferenceModule"]',container) : jQuery('input.popupReferenceModule',container);
 		var popupReferenceModule = popupReferenceModuleElement.val();
 		var sourceFieldElement = jQuery('input[class="sourceField"]',container);
 		if(!sourceFieldElement.length) {
@@ -1184,8 +1200,8 @@ Vtiger.Class('Vtiger_Index_Js', {
 	 * Function to get referenced module name
 	 */
 	getReferencedModuleName : function(parentElement) {
-		var referenceModuleElement = jQuery('input[name="popupReferenceModule"]',parentElement).length ? 
-		jQuery('input[name="popupReferenceModule"]',parentElement) : jQuery('input.popupReferenceModule',parentElement);
+		var referenceModuleElement = jQuery('input[name="popupReferenceModule"]',parentElement).length ?
+			jQuery('input[name="popupReferenceModule"]',parentElement) : jQuery('input.popupReferenceModule',parentElement);
 		return referenceModuleElement.val();
 	},
 
@@ -1215,7 +1231,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 		var quickCreateNode = jQuery('#quickCreateModules').find('[data-name="'+ referenceModuleName +'"]');
 		if(quickCreateNode.length <= 0) {
 			var notificationOptions = {
-				'title' : app.vtranslate('JS_NO_CREATE_OR_NOT_QUICK_CREATE_ENABLED')
+				'message' : app.vtranslate('JS_NO_CREATE_OR_NOT_QUICK_CREATE_ENABLED')
 			}
 			app.helper.showAlertNotification(notificationOptions);
 		}
@@ -1223,13 +1239,13 @@ Vtiger.Class('Vtiger_Index_Js', {
 	},
 
 	/**
-	* Function to get reference search params
-	*/
+	 * Function to get reference search params
+	 */
 	getReferenceSearchParams : function(element){
 		var tdElement = this.getParentElement(element);
 		var params = {};
-		var referenceModuleElement = jQuery('input[name="popupReferenceModule"]',tdElement).length ? 
-		jQuery('input[name="popupReferenceModule"]',tdElement) : jQuery('input.popupReferenceModule',tdElement);
+		var referenceModuleElement = jQuery('input[name="popupReferenceModule"]',tdElement).length ?
+			jQuery('input[name="popupReferenceModule"]',tdElement) : jQuery('input.popupReferenceModule',tdElement);
 		var searchModule = referenceModuleElement.val();
 		params.search_module = searchModule;
 		return params;
@@ -1279,8 +1295,8 @@ Vtiger.Class('Vtiger_Index_Js', {
 		var parent = element.closest('td');
 		// added to support from all views which may not be table format
 		if(parent.length === 0) {
-			parent = element.closest('.td').length ? 
-			element.closest('.td') : element.closest('.fieldValue');
+			parent = element.closest('.td').length ?
+				element.closest('.td') : element.closest('.fieldValue');
 		}
 		return parent;
 	},
@@ -1298,6 +1314,11 @@ Vtiger.Class('Vtiger_Index_Js', {
 		app.helper.showVerticalScroll(jQuery("#modnavigator #modules-menu"),{autoHideScrollbar:true});
 	},
 
+	modulesMenuClearIconTitle: function() {
+		jQuery('#modules-menu i').removeAttr('title');
+		jQuery('#modules-menu .custom-module').removeAttr('title');
+	},
+
 	registerChangeTemplateEvent: function (container, recordId) {
 		var sourceModule = container.find('#sourceModuleName').val();
 		var thisInstance = this;
@@ -1311,7 +1332,9 @@ Vtiger.Class('Vtiger_Index_Js', {
 	registerMoreRecentUpdatesClickEvent: function (container, recordId) {
 		var moduleName = container.find('#sourceModuleName').val();
 		container.find('.moreRecentUpdates').on('click', function () {
-			var recentUpdateURL = "index.php?view=Detail&mode=showRecentActivities&page=1&module=" + moduleName + "&record=" + recordId + "&tab_label=LBL_UPDATES";
+			moduleName = app.helper.purifyContent(moduleName);
+			recordId = app.helper.purifyContent(recordId);
+			var recentUpdateURL = "index.php?view=Detail&mode=showRecentActivities&page=1&module=" + encodeURIComponent(moduleName) + "&record=" + encodeURIComponent(recordId) + "&tab_label=LBL_UPDATES";
 			window.location.href = recentUpdateURL;
 		});
 	},
@@ -1364,7 +1387,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 			params['navigation'] = 'false';
 		}
 		else{
-		params['navigation'] = 'true';
+			params['navigation'] = 'true';
 		}
 
 		if (templateId) {
@@ -1477,9 +1500,9 @@ Vtiger.Class('Vtiger_Index_Js', {
 				//perform show preview only after 500ms in list view to support double click edit action
 				if (!currentTarget.data('preview-timer') && typeof href != 'undefined') {
 					currentTarget.data('preview-timer', setTimeout(function () {
-						 var data = app.convertUrlToDataParams(href);
-						 self.showQuickPreviewForId(data.record, data.module, app.getAppName(),'',true);
-						 currentTarget.data('preview-timer',null);
+						var data = app.convertUrlToDataParams(href);
+						self.showQuickPreviewForId(data.record, data.module, app.getAppName(),'',true);
+						currentTarget.data('preview-timer',null);
 					}, 500));
 				}
 			} else {
@@ -1490,7 +1513,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 
 		if(view === 'List') {
 			/*
-			* when reference display value is double clicked in list view, 
+			* when reference display value is double clicked in list view,
 			* should initiate inline edit instead of showing preview
 			*/
 			jQuery('body').on('dblclick', '.js-reference-display-value', function(e) {
@@ -1548,35 +1571,35 @@ Vtiger.Class('Vtiger_Index_Js', {
 		var completedValues = [];
 		for(var index in autoFillData){
 			var value = autoFillData[index];
-			var referenceContainer = thisInstance.getRelatedFieldElements(container, value); 
+			var referenceContainer = thisInstance.getRelatedFieldElements(container, value);
 			jQuery.each(data, function(datakey, datavalue){
 				for(var name in datavalue){
 					if(typeof datavalue[name] == 'object'){
 						var key = name;
 						var dataList = {
-								'name': datavalue[key].name,
-								'id' : datavalue[key].id
+							'name': datavalue[key].name,
+							'id' : datavalue[key].id
 						}
 
 						if(value.module == datavalue[key].module){
-								var autoFillElement = thisInstance.autoFillElement;
-								var autoFillData = value;
-								var popupReferenceModuleElement = autoFillElement.parent().parent().find('[name=popupReferenceModule]').length ? 
-										autoFillElement.parent().parent().find('[name=popupReferenceModule]') : autoFillElement.parent().parent().find('.popupReferenceModule');
-								var module = popupReferenceModuleElement.val();
-								var elementName = autoFillElement.attr('name');
-								var selectedName = container.find('#'+elementName+'_display').val();
-								var message = app.vtranslate('JS_OVERWRITE_AUTOFILL_MSG1')+' '+app.vtranslate('SINGLE_'+autoFillData.module)+" "+app.vtranslate('JS_OVERWRITE_AUTOFILL_MSG2')+" "+app.vtranslate('SINGLE_'+module)+' ('+selectedName+') '+app.vtranslate('SINGLE_'+autoFillData.module)+" ?";
-								var parentId = container.find('[name='+autoFillData.fieldname+']').val();
+							var autoFillElement = thisInstance.autoFillElement;
+							var autoFillData = value;
+							var popupReferenceModuleElement = autoFillElement.parent().parent().find('[name=popupReferenceModule]').length ?
+								autoFillElement.parent().parent().find('[name=popupReferenceModule]') : autoFillElement.parent().parent().find('.popupReferenceModule');
+							var module = popupReferenceModuleElement.val();
+							var elementName = autoFillElement.attr('name');
+							var selectedName = container.find('#'+elementName+'_display').val();
+							var message = app.vtranslate('JS_OVERWRITE_AUTOFILL_MSG1')+' '+app.vtranslate('SINGLE_'+autoFillData.module)+" "+app.vtranslate('JS_OVERWRITE_AUTOFILL_MSG2')+" "+app.vtranslate('SINGLE_'+module)+' ('+selectedName+') '+app.vtranslate('SINGLE_'+autoFillData.module)+" ?";
+							var parentId = container.find('[name='+autoFillData.fieldname+']').val();
 
-								if(parentId != dataList.id && parentId) {
-										if(jQuery.inArray(datavalue[key].module, completedValues) === -1) {
-											completedValues.push(datavalue[key].module);
-											thisInstance.confirmAndFillDetails(referenceContainer[key], dataList, message);
-										}		 
-								} else {
-										thisInstance.setReferenceFieldValue(referenceContainer[key], dataList);
+							if(parentId != dataList.id && parentId) {
+								if(jQuery.inArray(datavalue[key].module, completedValues) === -1) {
+									completedValues.push(datavalue[key].module);
+									thisInstance.confirmAndFillDetails(referenceContainer[key], dataList, message);
 								}
+							} else {
+								thisInstance.setReferenceFieldValue(referenceContainer[key], dataList);
+							}
 						}
 					}
 				}
@@ -1587,11 +1610,11 @@ Vtiger.Class('Vtiger_Index_Js', {
 	confirmAndFillDetails : function(container, data, message) {
 		var thisInstance = this;
 		app.helper.showConfirmationBox({'message' : message}).then(
-				function(e) {
-						thisInstance.setReferenceFieldValue(container, data);
-				},
-				function(error, err){
-				}
+			function(e) {
+				thisInstance.setReferenceFieldValue(container, data);
+			},
+			function(error, err){
+			}
 		);
 	},
 
@@ -1619,7 +1642,7 @@ Vtiger.Class('Vtiger_Index_Js', {
 		var module;
 		if(!resultData.module) {
 			var autoFillElement = this.autoFillElement;
-			var popupReferenceModuleElement = autoFillElement.parent().parent().find('[name=popupReferenceModule]').length ? 
+			var popupReferenceModuleElement = autoFillElement.parent().parent().find('[name=popupReferenceModule]').length ?
 				autoFillElement.parent().parent().find('[name=popupReferenceModule]') : autoFillElement.parent().parent().find('.popupReferenceModule');
 			module = popupReferenceModuleElement.val();
 		}else {
@@ -1629,11 +1652,11 @@ Vtiger.Class('Vtiger_Index_Js', {
 			return;
 
 		var params = {
-				module: module,
-				action: 'RelationAjax',
-				mode: 'getRelatedRecordInfo',
-				id: resultData.id
-			};
+			module: module,
+			action: 'RelationAjax',
+			mode: 'getRelatedRecordInfo',
+			id: resultData.id
+		};
 
 		app.request.post({'data' : params}).then(function(err, data){
 			if(err == null){
