@@ -36,7 +36,7 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 		//$this->set('assigned_user_id', $currentUserModel->getId());
 		$this->getModule()->saveRecord($this);
 		$documentIds = $this->get('documentids');
-		if (!empty ($documentIds)) {
+		if (!empty ($documentIds) && $documentIds != "[]") { /* json_encoded check for empty */
 			$this->deleteDocumentLink();
 			$this->saveDocumentDetails();
 		}
@@ -48,16 +48,18 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 	public function send($addToQueue = false) {
 		$currentUserModel = Users_Record_Model::getCurrentUserModel();
 		$rootDirectory = vglobal('root_directory');
+		$logo = false;
 
 		$mailer = Emails_Mailer_Model::getInstance();
 		$mailer->IsHTML(true);
+		$id = isset($_REQUEST['id']) ? $_REQUEST['id'] : null;
 
 		$fromEmail = $this->getFromEmailAddress();
 		$replyTo = $this->getReplyToEmail();
 		$userName = $currentUserModel->getName();
 
 		// To eliminate the empty value of an array
-		$toEmailInfo = array_filter($this->get('toemailinfo'));
+		$toEmailInfo = $this->get('toemailinfo') ? array_filter($this->get('toemailinfo')) : array();
 		$emailsInfo = array();
 		foreach ($toEmailInfo as $id => $emails) {
 			foreach($emails as $key => $value){
@@ -65,6 +67,7 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 			}
 		}
 
+        $allEligibleEmails = array();
 		$toEmailInfo = array_map("unserialize", array_unique(array_map("serialize", array_map("array_unique", $toEmailInfo))));
 		$toFieldData = array_diff(explode(',', $this->get('saved_toid')), $emailsInfo);
 		$toEmailsData = array();
@@ -78,7 +81,30 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 		// Merge Users module merge tags based on current user.
 		$mergedDescription = getMergedDescription($this->get('description'), $currentUserModel->getId(), 'Users');
 		$mergedSubject = getMergedDescription($this->get('subject'),$currentUserModel->getId(), 'Users');
-		foreach($toEmailInfo as $id => $emails) {
+                $selectedIds = array();
+        
+        // push all emails to one single array
+		foreach($toEmailInfo as $selectedId => $selectedEmails) {
+            
+            // Pushing all ids to one single array
+            if($selectedId){
+                array_push($selectedIds,$selectedId);
+            }
+            
+            // If selected emails is not an array, then make it as array
+            if(!is_array($selectedEmails)){
+                $selectedEmails = array($selectedEmails);
+            }
+            
+            // For selectedEmails check and push to emails array
+            foreach($selectedEmails as $selectedEmail){
+                $emails=array();
+                if(trim($selectedEmail)){
+                    array_push($emails, $selectedEmail);
+                }
+      //      }
+      //  }
+        
 			$inReplyToMessageId = ''; 
 			$generatedMessageId = '';
 			$mailer->reinitialize();
@@ -103,8 +129,8 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 						$inReplyToMessageId = $generatedMessageId;
 					}
 					// Apply merge for non-Users module merge tags.
-					$description = getMergedDescription($mergedDescriptionWithHyperLinkConversion, $id, $parentModule);
-					$subject = getMergedDescription($mergedSubject, $id, $parentModule);
+					$description = getMergedDescription($mergedDescriptionWithHyperLinkConversion, $selectedId, $parentModule);
+					$subject = getMergedDescription($mergedSubject, $selectedId, $parentModule);
 				} else {
 					// Re-merge the description for user tags based on actual user.
 					$description = getMergedDescription($mergedDescriptionWithHyperLinkConversion, $id, 'Users');
@@ -127,56 +153,65 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 				$logo = true;
 			}
 
-			foreach($emails as $email) {
-				$mailer->Body = $description;
-				if ($parentModule) {
-					$mailer->Body = $this->convertUrlsToTrackUrls($mailer->Body, $id);;
-					$mailer->Body .= $this->getTrackImageDetails($id, $this->isEmailTrackEnabled($parentModule));
-				}
-				//Checking whether user requested to add signature or not
-				if($this->get('signature') == 'Yes'){
-					$mailer->Signature = $currentUserModel->get('signature');
-					if($mailer->Signature != '') {
-						$mailer->Body.= '<br><br>'.decode_html($mailer->Signature);
-					}
-				}
-				$mailer->Subject = decode_html(strip_tags($subject));
+            // Adding all recipients in mail
+            foreach($emails as $email) {
+                array_push($allEligibleEmails,$email);
+                $mailer->AddAddress($email);
+            }
+            $mailer->Body = $description;
+            if ($parentModule) {
+                $mailer->Body = $this->convertUrlsToTrackUrls($mailer->Body, $id);;
+                $mailer->Body .= $this->getTrackImageDetails($id, $this->isEmailTrackEnabled($parentModule));
+            }
+            //Checking whether user requested to add signature or not
+            if($this->get('signature') == 'Yes'){
+                $mailer->Signature = $currentUserModel->get('signature');
+                if($mailer->Signature != '') {
+                    $mailer->Body.= '<br><br>'.decode_html($mailer->Signature);
+                }
+            }
+            $mailer->Subject = decode_html(strip_tags($subject));
 
-				$plainBody = decode_emptyspace_html($description);
-				$plainBody = preg_replace(array("/<p>/i","/<br>/i","/<br \/>/i"),array("\n","\n","\n"),$plainBody);
-				$plainBody .= "\n\n".$currentUserModel->get('signature');
-				$plainBody = strip_tags($plainBody);
-				$plainBody = Emails_Mailer_Model::convertToAscii($plainBody);
-				$plainBody = $this->convertUrlsToTrackUrls($plainBody, $id,'plain');
-				$mailer->AltBody = $plainBody;
-				$mailer->AddAddress($email);
+            $plainBody = decode_emptyspace_html($description);
+            $plainBody = preg_replace(array("/<p>/i","/<br>/i","/<br \/>/i"),array("\n","\n","\n"),$plainBody);
+            $plainBody .= "\n\n".$currentUserModel->get('signature');
+            $plainBody = strip_tags($plainBody);
+            $plainBody = Emails_Mailer_Model::convertToAscii($plainBody);
+            $plainBody = $this->convertUrlsToTrackUrls($plainBody, $id,'plain');
+            $mailer->AltBody = $plainBody;
+     //       $mailer->AddAddress($email);
 
-				//Adding attachments to mail
-				if(is_array($attachments)) {
-					foreach($attachments as $attachment) {
-						$fileNameWithPath = $rootDirectory.$attachment['path'].$attachment['fileid']."_".$attachment['attachment'];
-						if(is_file($fileNameWithPath)) {
-							$mailer->AddAttachment($fileNameWithPath, $attachment['attachment']);
-						}
-					}
-				}
-				if ($logo) {
-					$companyDetails = Vtiger_CompanyDetails_Model::getInstanceById();
-					$companyLogoDetails = $companyDetails->getLogo();
-					//While sending email template and which has '$logo$' then it should replace with company logo
-					$mailer->AddEmbeddedImage($companyLogoDetails->get('imagepath'), 'companyLogo', 'attachment', 'base64', 'image/jpg');
-				}
+            //Adding attachments to mail
+            if(is_array($attachments)) {
+                foreach($attachments as $attachment) {
+                    $fileNameWithPath = $rootDirectory.$attachment['filenamewithpath'];
+                    if(is_file($fileNameWithPath)) {
+                        $mailer->AddAttachment($fileNameWithPath, $attachment['attachment']);
+                    }
+                }
+            }
+            if ($logo) {
+                $companyDetails = Vtiger_CompanyDetails_Model::getInstanceById();
+                $companyLogoDetails = $companyDetails->getLogo();
+                //While sending email template and which has '$logo$' then it should replace with company logo
+                $mailer->AddEmbeddedImage($companyLogoDetails->get('imagepath'), 'companyLogo', 'attachment', 'base64', 'image/jpg');
+            }
 
-				$ccs = array_filter(explode(',',$this->get('ccmail')));
-				$bccs = array_filter(explode(',',$this->get('bccmail')));
+            $ccs = array_filter(explode(',',$this->get('ccmail')));
+            $bccs = array_filter(explode(',',$this->get('bccmail')));
 
-				if(!empty($ccs)) {
-					foreach($ccs as $cc) $mailer->AddCC($cc);
-				}
-				if(!empty($bccs)) {
-					foreach($bccs as $bcc) $mailer->AddBCC($bcc);
-				}
-			}
+            if(!empty($ccs)) {
+                foreach($ccs as $cc) {
+                    array_push($allEligibleEmails,$cc);
+                    $mailer->AddCC($cc);
+                }
+            }
+            if(!empty($bccs)) {
+                foreach($bccs as $bcc) {
+                    array_push($allEligibleEmails,$bcc);
+                    $mailer->AddBCC($bcc);
+                }
+            }
 			// to convert external css to inline css
 			$mailer->Body = Emails_Mailer_Model::convertCssToInline($mailer->Body);	
 			//To convert image url to valid
@@ -187,9 +222,10 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 				$status = $mailer->Send(true);
 			}
 			if(!$status) {
-				$status = $mailer->getError();
-				//If mailer error, then update emailflag as saved
-				if($status){
+				// Before inspecting for mailer error do a explict check on its configuration.
+				$err = $mailer->_serverConfigured ? $mailer->getError() : vtranslate("LBL_MAIL_SERVER_DESCRIPTION", "Settings:Vtiger");
+				// If mailer error, then update emailflag as saved
+				if($err){
 					$this->updateEmailFlag();
 				}
 			} else {
@@ -207,10 +243,14 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 					if (function_exists('mb_convert_encoding')) {
 						$folderName = mb_convert_encoding($folderName, "UTF7-IMAP", "UTF-8");
 					}
-					imap_append($connector->mBox, $connector->mBoxUrl.$folderName, $message, "\\Seen");
+					// propogate change to connected imap mailbox if valid.
+					if ($connector->mBox) {
+						imap_append($connector->mBox, $connector->mBoxUrl.$folderName, $message, "\\Seen");
+					}
 				}
 			}
 		}
+	}
 		return $status;
 	}
 
@@ -218,7 +258,7 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 	 * Returns the From Email address that will be used for the sent mails
 	 * @return <String> - from email address
 	 */
-	function getFromEmailAddress() {
+	static function getFromEmailAddress() {
 		$db = PearDatabase::getInstance();
 		$currentUserModel = Users_Record_Model::getCurrentUserModel();
 
@@ -245,11 +285,24 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 		$attachmentsList = array();
 		if($numOfRows) {
 			for($i=0; $i<$numOfRows; $i++) {
-				$attachmentsList[$i]['fileid'] = $db->query_result($attachmentRes, $i, 'attachmentsid');
-				$attachmentsList[$i]['attachment'] = decode_html($db->query_result($attachmentRes, $i, 'name'));
-				$path = $db->query_result($attachmentRes, $i, 'path');
+                                $attachmentId = $db->query_result($attachmentRes, $i, 'attachmentsid');
+                                $rawFileName = $db->query_result($attachmentRes, $i, 'name');
+                                $storedName = $db->query_result($attachmentRes, $i, 'storedname');
+                                $path = $db->query_result($attachmentRes, $i, 'path');
+                                if($storedName) { 
+                                    $filename = $storedName;
+                                } else {
+                                    $filename = $rawFileName;
+                                }
+                                $attachmentsList[$i]['attachment'] = decode_html($rawFileName);
+                                $attachmentsList[$i]['fileid'] = $attachmentId;
+                                $attachmentsList[$i]['storedname'] = decode_html($storedName);
 				$attachmentsList[$i]['path'] = $path;
-				$attachmentsList[$i]['size'] = filesize($path.$attachmentsList[$i]['fileid'].'_'.$attachmentsList[$i]['attachment']);
+                                $saved_filename = $attachmentId."_".$filename;
+                                $filenamewithpath = $path.$saved_filename;
+                                $filesize = filesize($filenamewithpath);
+                                $attachmentsList[$i]['filenamewithpath'] = $filenamewithpath;
+				$attachmentsList[$i]['size'] = $filesize;
 				$attachmentsList[$i]['type'] = $db->query_result($attachmentRes, $i, 'type');
 				$attachmentsList[$i]['cid'] = $db->query_result($attachmentRes, $i, 'cid');
 			}
@@ -299,7 +352,9 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 				$documentsList[$i]['path'] = $db->query_result($documentRes, $i, 'path');
 				$documentsList[$i]['fileid'] = $db->query_result($documentRes, $i, 'attachmentsid');
 				$documentsList[$i]['attachment'] = decode_html($db->query_result($documentRes, $i, 'name'));
+                $documentsList[$i]['storedname'] = decode_html($db->query_result($documentRes, $i, 'storedname'));
 				$documentsList[$i]['type'] = $db->query_result($documentRes, $i, 'type');
+				$documentsList[$i]['filenamewithpath'] = $documentsList[$i]['path'].$documentsList[$i]['fileid'].'_'.$documentsList[$i]['storedname'];
 			}
 		}
 		return $documentsList;
@@ -325,15 +380,16 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 	 * Function to save details of document and email
 	 */
 	public function saveDocumentDetails() {
+            $documentIds = json_decode($this->get('documentids'), true);
+            if(!empty($documentIds)) {
 		$db = PearDatabase::getInstance();
 		$record = $this->getId();
-
-		$documentIds = array_unique($this->get('documentids'));
-
-		$count = count($documentIds);
+                $documentIds = array_unique($documentIds);
+		$count = php7_count($documentIds);
 		for ($i=0; $i<$count; $i++) {
 			$db->pquery("INSERT INTO vtiger_senotesrel(crmid, notesid) VALUES(?, ?)", array($record, $documentIds[$i]));
 		}
+            }
 	}
 
 	/**
@@ -344,7 +400,7 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 		$db = PearDatabase::getInstance();
 		$query = 'DELETE FROM vtiger_senotesrel where crmid=?';
 		$params = array($this->getId());
-		if(count($idList) > 0) {
+		if(php7_count($idList) > 0) {
 			$query .= 'AND notesid IN ('.generateQuestionMarks($idList).')';
 			$params = array_merge($params,$idList);
 		}
@@ -358,7 +414,7 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 	public function deleteAttachment($emailAttachmentDetails = array()) {
 		$db = PearDatabase::getInstance();
 
-		if(count($emailAttachmentDetails) <= 0) {
+		if(php7_count($emailAttachmentDetails) <= 0) {
 			return;
 		}
 		$attachmentIdList = array();
@@ -386,7 +442,7 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 			}
 		}
 		if (!empty ($documentIds)) {
-			$count = count($documentIds);
+			$count = php7_count($documentIds);
 			for ($i=0; $i<$count; $i++) {
 				try {
 					$documentRecordModel = Vtiger_Record_Model::getInstanceById($documentIds[$i], 'Documents');
@@ -588,14 +644,22 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 	public function trackClicks($parentId) {
 		$db = PearDatabase::getInstance();
 		$recordId = $this->getId();
+		$currentDateTime = date('Y-m-d H:i:s');
+		
+		$db->pquery("INSERT INTO vtiger_email_access(crmid, mailid, accessdate, accesstime) VALUES(?, ?, ?, ?)", array($parentId, $recordId, date('Y-m-d'),$currentDateTime ));
 
-		$db->pquery("INSERT INTO vtiger_email_access(crmid, mailid, accessdate, accesstime) VALUES(?, ?, ?, ?)", array($parentId, $recordId, date('Y-m-d'), date('Y-m-d H:i:s')));
-
-		$result = $db->pquery("SELECT 1 FROM vtiger_email_track WHERE crmid = ? AND mailid = ?", array($parentId, $recordId));
-		if ($db->num_rows($result) > 0) {
-			$db->pquery("UPDATE vtiger_email_track SET click_count = click_count+1 WHERE crmid = ? AND mailid = ?", array($parentId, $recordId));
+		$result = $db->pquery("SELECT access_count,click_count FROM vtiger_email_track WHERE crmid = ? AND mailid = ?", array($parentId, $recordId));
+		$accessCount = $db->query_result($result,0,'access_count');
+		if ($db->num_rows($result)>0) {
+			$updatedAccessCount = $accessCount;
+			
+			//If click is unique (i.e first click on mail), then also increase open count to 1
+			if($accessCount == 0)
+				$updatedAccessCount = $accessCount+1;
+			
+			$db->pquery("UPDATE vtiger_email_track SET click_count = click_count+1,access_count=? WHERE crmid = ? AND mailid = ?", array($updatedAccessCount, $parentId, $recordId));
 		} else {
-			$db->pquery("INSERT INTO vtiger_email_track(crmid, mailid, click_count) values(?, ?, ?)", array($parentId, $recordId, 1));
+			$db->pquery("INSERT INTO vtiger_email_track(crmid, mailid, access_count,click_count) values(?, ?, ?,?)", array($parentId, $recordId, 1,1));
 		}
 	}
 
@@ -661,16 +725,15 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 		return $content;
 	}
 
-	public function getTrackUrlForClicks($parentId, $redirectUrl = false) {
-		$siteURL = vglobal('site_URL');
-		$applicationKey = vglobal('application_unique_key');
-		$recordId = $this->getId();
-		$trackURL = "$siteURL/modules/Emails/actions/TrackAccess.php?record=$recordId&parentId=$parentId&applicationKey=$applicationKey&method=click";
-		if ($redirectUrl) {
-			$encodedRedirUrl = rawurlencode($redirectUrl);
-			$trackURL .= "&redirectUrl=$encodedRedirUrl";
-		}
-		return $trackURL;
+	public function getTrackUrlForClicks($parentId, $redirectUrl = false, $linkName = false) {
+                $params = array();
+                $recordId = $this->getId();
+		if($redirectUrl) $params['redirectUrl'] = $redirectUrl;
+                if($linkName) $params['linkName'] = $linkName;
+                $params['record'] = $recordId;
+                $params['parentId'] = $parentId;
+                $params['method'] = 'click';
+                return Vtiger_Functions::generateTrackingURL($params);
 	}
 
 	/**
@@ -755,4 +818,21 @@ class Emails_Record_Model extends Vtiger_Record_Model {
 
 		return $replyTo;
 	}
+        
+        
+        /**
+	 * Function to check if email is opened within 1 hour.
+	 * @param <Integer> $parentId Parent record id
+	 * @return <Boolean> Returns TRUE if opened within 1 hr else FALSE.
+	 */
+	function isEmailOpenedRecently($parentId) {
+		$db = PearDatabase::getInstance();
+		$lastOpenTime = date('Y-m-d H:i:s', strtotime("-1 hours"));
+		
+		$result = $db->pquery("SELECT 1 FROM vtiger_email_access WHERE crmid = ? AND mailid = ? AND accesstime > ?", array($parentId, $this->getId(), $lastOpenTime));
+		if($db->num_rows($result)) {
+			return true;
+		}
+		return false;
+	}
 }
