@@ -69,9 +69,14 @@ class Install_InitSchema_Model {
 					$oldVersion = $newVersion;
 					break;
 				}
+				// Fix version numbering
+				if (strlen($oldVersion."") < 3) $oldVersion .= "0";
+				if (strlen($newVersion."") < 3) $newVersion .= "0";
+
 				$oldVersion = str_replace(array('.', ' '), '', $oldVersion);
 				$newVersion = str_replace(array('.', ' '), '', $newVersion);
 				$filename =  "modules/Migration/schema/".$oldVersion."_to_".$newVersion.".php";
+				
 				if(is_file($filename)) {
 					include($filename);
 				}
@@ -320,6 +325,12 @@ class Install_InitSchema_Model {
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",23,3,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",23,4,0)", array());
 
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",25,0,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",25,1,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",25,2,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",25,3,0)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",25,4,0)", array());
+
         $adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",26,0,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",26,1,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId1.",26,2,0)", array());
@@ -424,8 +435,13 @@ class Install_InitSchema_Model {
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",23,3,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",23,4,0)", array());
 
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",25,0,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",25,1,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",25,2,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",25,3,0)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",25,4,0)", array());
 
-        	$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",26,0,0)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",26,0,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",26,1,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",26,2,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId2.",26,3,0)", array());
@@ -529,6 +545,11 @@ class Install_InitSchema_Model {
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId3.",23,3,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId3.",23,4,0)", array());
 
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId3.",25,0,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId3.",25,1,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId3.",25,2,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId3.",25,3,0)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId3.",25,4,0)", array());
 
         $adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId3.",26,0,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId3.",26,1,0)", array());
@@ -632,6 +653,11 @@ class Install_InitSchema_Model {
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId4.",23,3,0)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId4.",23,4,0)", array());
 
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId4.",25,0,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId4.",25,1,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId4.",25,2,1)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId4.",25,3,0)", array());
+		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId4.",25,4,0)", array());
 
         $adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId4.",26,0,1)", array());
 		$adb->pquery("INSERT INTO vtiger_profile2standardpermissions VALUES (".$profileId4.",26,1,1)", array());
@@ -880,6 +906,7 @@ class Install_InitSchema_Model {
 		Vtiger_Cron::register( 'SendReminder', 'cron/SendReminder.service', 900, 'Calendar', 1, 3, 'Recommended frequency for SendReminder is 15 mins');
 		Vtiger_Cron::register( 'ScheduleReports', 'cron/modules/Reports/ScheduleReports.service', 900, 'Reports', 1, 4, 'Recommended frequency for ScheduleReports is 15 mins');
 		Vtiger_Cron::register( 'MailScanner', 'cron/MailScanner.service', 900, 'Settings', 1, 5, 'Recommended frequency for MailScanner is 15 mins');
+		Vtiger_Cron::register( 'Oauth2TokenRefresher', "cron/modules/Oauth2/TokenRefresher.service", 45 * 60, 1, 0, 'Recommended frequency for TokenRefresher is 45 mins');
 	}
 
 	/**
