@@ -59,8 +59,10 @@ class Install_Utils_Model {
 		$directiveValues = array();
 		if (ini_get('safe_mode') == '1' || stripos(ini_get('safe_mode'), 'On') > -1)
 			$directiveValues['safe_mode'] = 'On';
-		if (ini_get('display_errors') != '1' || stripos(ini_get('display_errors'), 'Off') > -1)
-			$directiveValues['display_errors'] = 'Off';
+		/* if (ini_get('display_errors') != '1' || stripos(ini_get('display_errors'), 'Off') > -1)
+			$directiveValues['display_errors'] = 'Off'; */
+		if (ini_get('display_errors') == '1' || stripos(ini_get('display_errors'), 'On') > -1)
+            $directiveValues['display_errors'] = 'On';
 		if (ini_get('file_uploads') != '1' || stripos(ini_get('file_uploads'), 'Off') > -1)
 			$directiveValues['file_uploads'] = 'Off';
 		if (ini_get('register_globals') == '1' || stripos(ini_get('register_globals'), 'On') > -1)
@@ -71,19 +73,6 @@ class Install_Utils_Model {
 			$directiveValues['max_execution_time'] = ini_get('max_execution_time');
 		if (ini_get('memory_limit') < 32)
 			$directiveValues['memory_limit'] = ini_get('memory_limit');
-			$errorReportingValue = E_WARNING & ~E_NOTICE;
-                if(version_compare(PHP_VERSION, '5.5.0') >= 0){
-                    $errorReportingValue = E_WARNING & ~E_NOTICE & ~E_DEPRECATED & ~E_STRICT;
-                }
-                else if(version_compare(PHP_VERSION, '5.3.0') >= 0) {
-			$errorReportingValue = E_WARNING & ~E_NOTICE & ~E_DEPRECATED;
-		}
-		if (ini_get('error_reporting') != $errorReportingValue)
-			$directiveValues['error_reporting'] = 'NOT RECOMMENDED';
-		if (ini_get('log_errors') == '1' || stripos(ini_get('log_errors'), 'On') > -1)
-			$directiveValues['log_errors'] = 'On';
-		if (ini_get('short_open_tag') == '1' || stripos(ini_get('short_open_tag'), 'On') > -1)
-			$directiveValues['short_open_tag'] = 'On';
 
 		return $directiveValues;
 	}
@@ -94,15 +83,12 @@ class Install_Utils_Model {
 	 */
 	public static $recommendedDirectives = array (
 		'safe_mode' => 'Off',
-		'display_errors' => 'On',
+		'display_errors' => 'Off',
 		'file_uploads' => 'On',
 		'register_globals' => 'On',
 		'output_buffering' => 'On',
 		'max_execution_time' => '0',
-		'memory_limit' => '32',
-		'error_reporting' => 'E_WARNING & ~E_NOTICE',
-		'log_errors' => 'Off',
-		'short_open_tag' => 'Off'
+		'memory_limit' => '32'
 	);
 
 	/**
@@ -110,12 +96,6 @@ class Install_Utils_Model {
 	 * @return type
 	 */
 	public static function getRecommendedDirectives(){
-            if(version_compare(PHP_VERSION, '5.5.0') >= 0){
-                self::$recommendedDirectives['error_reporting'] = 'E_WARNING & ~E_NOTICE & ~E_DEPRECATED & ~E_STRICT';
-            }
-	    else if(version_compare(PHP_VERSION, '5.3.0') >= 0) {
-			self::$recommendedDirectives['error_reporting'] = 'E_WARNING & ~E_NOTICE & ~E_DEPRECATED';
-		}
 		return self::$recommendedDirectives;
 	}
 
@@ -126,8 +106,8 @@ class Install_Utils_Model {
 	public static function getSystemPreInstallParameters() {
 		$preInstallConfig = array();
 		// Name => array( System Value, Recommended value, supported or not(true/false) );
-		$preInstallConfig['LBL_PHP_VERSION']	= array(phpversion(), '5.4.0', (version_compare(phpversion(), '5.4.0', '>=')));
-		$preInstallConfig['LBL_IMAP_SUPPORT']	= array(function_exists('imap_open'), true, (function_exists('imap_open') == true));
+		$preInstallConfig['LBL_PHP_VERSION']	= array(phpversion(), '7.0+,8.0+', (version_compare(phpversion(), '7.0', '>=')));
+		//$preInstallConfig['LBL_IMAP_SUPPORT']	= array(function_exists('imap_open'), true, (function_exists('imap_open') == true));
 		$preInstallConfig['LBL_ZLIB_SUPPORT']	= array(function_exists('gzinflate'), true, (function_exists('gzinflate') == true));
 
 		if ($preInstallConfig['LBL_PHP_VERSION'] >= '5.5.0') {
@@ -136,6 +116,8 @@ class Install_Utils_Model {
 
 		$preInstallConfig['LBL_OPEN_SSL']		= array(extension_loaded('openssl'), true, extension_loaded('openssl'));
 		$preInstallConfig['LBL_CURL']			= array(extension_loaded('curl'), true, extension_loaded('curl'));
+		$preInstallConfig['LBL_IMAP_SUPPORT']	= array(extension_loaded('imap'), true, (extension_loaded('imap') == true));
+		$preInstallConfig['LBL_MB_STRING']	    = array(extension_loaded('mbstring'), true, (extension_loaded('mbstring') == true));
 
 		$gnInstalled = false;
 		if(!function_exists('gd_info')) {
@@ -330,6 +312,25 @@ class Install_Utils_Model {
 		return $mysql_server_version;
 	}
 
+	/**
+	 * Function to check sql_mode configuration
+	 * @param DbConnection $conn 
+	 * @return boolean
+	 */
+	public static function isMySQLSqlModeFriendly($conn) {
+		$rs = $conn->Execute("SHOW VARIABLES LIKE 'sql_mode'");
+		if ($rs && ($row = $rs->fetchRow())) {
+			$values = explode(',', strtoupper($row['Value']));
+			$unsupported = array('ONLY_FULL_GROUP_BY', 'STRICT_TRANS_TABLES', 'NO_ZERO_IN_DATE', 'NO_ZERO_DATE');
+			foreach ($unsupported as $check) {
+				if (in_array($check, $values)) {
+					return false;
+				}
+			}
+		}
+		return true;
+	}
+
 	/**
 	 * Function checks the database connection
 	 * @param <String> $db_type
@@ -351,9 +352,15 @@ class Install_Utils_Model {
 		$db_creation_failed = false; // did we try to create a database and fail?
 		$db_exist_status = false; // does the database exist?
 		$db_utf8_support = false; // does the database support utf8?
+		$db_sqlmode_support = false; // does the database having friendly sql_mode?
 
 		//Checking for database connection parameters
 		if($db_type) {
+			// Backward compatible mode for adodb library.
+			if ($db_type == 'mysqli') {
+				mysqli_report(MYSQLI_REPORT_ALL ^ MYSQLI_REPORT_STRICT ^ MYSQLI_REPORT_INDEX);
+			}
+			
 			$conn = NewADOConnection($db_type);
 			$db_type_status = true;
 			if(@$conn->Connect($db_hostname,$db_username,$db_password)) {
@@ -362,7 +369,9 @@ class Install_Utils_Model {
 				if(self::isMySQL($db_type)) {
 					$mysql_server_version = self::getMySQLVersion($serverInfo);
 				}
-				if($create_db) {
+				$conn->Execute("SET SESSION sql_mode = 'NO_ENGINE_SUBSTITUTION'"); /* force friendly mode */
+				$db_sqlmode_support = self::isMySQLSqlModeFriendly($conn);
+				if($create_db && $db_sqlmode_support) {
 					// drop the current database if it exists
 					$dropdb_conn = NewADOConnection($db_type);
 					if(@$dropdb_conn->Connect($db_hostname, $root_user, $root_password, $db_name)) {
@@ -375,6 +384,7 @@ class Install_Utils_Model {
 					$db_creation_failed = true;
 					$createdb_conn = NewADOConnection($db_type);
 					if(@$createdb_conn->Connect($db_hostname, $root_user, $root_password)) {
+						$createdb_conn->Execute("SET SESSION sql_mode = 'NO_ENGINE_SUBSTITUTION'"); /* force friendly mode */
 						$query = "CREATE DATABASE ".$db_name;
 						if($create_utf8_db == 'true') {
 							if(self::isMySQL($db_type))
@@ -407,13 +417,17 @@ class Install_Utils_Model {
 			$error_msg_info = getTranslatedString('MSG_LIST_REASONS', 'Install').':<br>
 					-  '.getTranslatedString('MSG_DB_PARAMETERS_INVALID', 'Install').'
 					-  '.getTranslatedString('MSG_DB_USER_NOT_AUTHORIZED', 'Install');
-		} elseif(self::isMySQL($db_type) && $mysql_server_version < 4.1) {
+		} elseif(self::isMySQL($db_type) && version_compare($mysql_server_version,4.1,'<')) {
 			$error_msg = $mysql_server_version.' -> '.getTranslatedString('ERR_INVALID_MYSQL_VERSION', 'Install');
+		} elseif(!$db_sqlmode_support) {
+			$error_msg = getTranslatedString('ERR_DB_SQLMODE_NOTFRIENDLY', 'Install');
 		} elseif($db_creation_failed) {
 			$error_msg = getTranslatedString('ERR_UNABLE_CREATE_DATABASE', 'Install').' '.$db_name;
 			$error_msg_info = getTranslatedString('MSG_DB_ROOT_USER_NOT_AUTHORIZED', 'Install');
 		} elseif(!$db_exist_status) {
 			$error_msg = $db_name.' -> '.getTranslatedString('ERR_DB_NOT_FOUND', 'Install');
+		} elseif(!$db_utf8_support) {
+			$error_msg = $db_name.' -> '.getTranslatedString('ERR_DB_NOT_UTF8', 'Install');
 		} else {
 			$dbCheckResult['flag'] = true;
 			return $dbCheckResult;
@@ -437,7 +451,7 @@ class Install_Utils_Model {
 			if ($handle = opendir($moduleFolder)) {
 				while (false !== ($file = readdir($handle))) {
 					$packageNameParts = explode(".",$file);
-					if($packageNameParts[count($packageNameParts)-1] != 'zip'){
+					if($packageNameParts[php7_count($packageNameParts)-1] != 'zip'){
 						continue;
 					}
 					array_pop($packageNameParts);
@@ -460,4 +474,13 @@ class Install_Utils_Model {
 			}
 		}
 	}
+
+	/* 
+	 * Register installed user detail to inform about product updates and news.
+	 */
+	public static function registerUser($name, $email, $industry) {
+		require_once 'vtlib/Vtiger/Net/Client.php';
+		$client = new Vtiger_Net_Client("https://stats.vtiger.com/register.php");
+		@$client->doPost(array("name" => $name, "email" => $email, "industry" => $industry), 5);
+	}
 }
