@@ -77,8 +77,8 @@ class Inventory_Record_Model extends Vtiger_Record_Model {
 		$productIdsList = array();
 		for ($i=1;$i<=$productsCount; $i++) {
 			$product = $relatedProducts[$i];
-			$productId = $product['hdnProductId'.$i];
-			$totalAfterDiscount = $product['totalAfterDiscount'.$i];
+			$productId = isset($product['hdnProductId'.$i]) ? $product['hdnProductId'.$i] : "";
+			$totalAfterDiscount = isset($product['totalAfterDiscount'.$i]) ? $product['totalAfterDiscount'.$i]:"";
 
 			if ($taxtype == 'individual') {
 				$taxDetails = getTaxDetailsForProduct($productId, 'all');
@@ -124,13 +124,13 @@ class Inventory_Record_Model extends Vtiger_Record_Model {
                 $preTaxTotal+=$totalAfterDiscount;
 			}
 
-			if ($relatedProducts[$i]['entityType'.$i] == 'Products') {
+			if (isset($relatedProducts[$i]['entityType'.$i]) && $relatedProducts[$i]['entityType'.$i] == 'Products') {
 				$productIdsList[] = $productId;
 			}
 		}
 
         //Updating Pre tax total if not calculated from individual taxtype
-        if (!$preTaxTotal) {
+        if (!isset($preTaxTotal)) {
     		$preTaxTotal = (float)$relatedProducts[1]['final_details']['hdnSubTotal']
     						+ (float)$relatedProducts[1]['final_details']['shipping_handling_charge']
     						- (float)$relatedProducts[1]['final_details']['discountTotal_final'];
@@ -208,7 +208,7 @@ class Inventory_Record_Model extends Vtiger_Record_Model {
 			for ($i=1; $i<=$productsCount; $i++) {
 				$product = $relatedProducts[$i];
 				$productId = $product['hdnProductId'.$i];
-				$imageDetails = $imageDetailsList[$productId];
+				$imageDetails = isset($imageDetailsList[$productId]) ? $imageDetailsList[$productId] : "";
 				if ($imageDetails) {
 					$relatedProducts[$i]['productImage'.$i] = $imageDetails[0]['path'].'_'.$imageDetails[0]['orgname'];
 				}
@@ -349,8 +349,8 @@ class Inventory_Record_Model extends Vtiger_Record_Model {
 
 		$productIdsList = array();
 		foreach ($productDetails as $key => $lineItemDetail) {
-			$productId	= $lineItemDetail['hdnProductId'.$key];
-			$entityType = $lineItemDetail['entityType'.$key];
+			$productId	= isset($lineItemDetail['hdnProductId'.$key]) ? $lineItemDetail['hdnProductId'.$key] : "";
+			$entityType = isset($lineItemDetail['entityType'.$key]) ? $lineItemDetail['entityType'.$key] : "";
 			$productIdsList[$entityType][] = $productId;
 		}
 
@@ -362,19 +362,18 @@ class Inventory_Record_Model extends Vtiger_Record_Model {
 
 		//Getting image details of each product
 		$imageDetailsList = array();
-		if ($productIdsList['Products']) {
+		if (isset($productIdsList['Products']) && $productIdsList['Products']) {
 			$imageDetailsList = Products_Record_Model::getProductsImageDetails($productIdsList['Products']);
 		}
 
 		foreach ($productDetails as $key => $lineItemDetail) {
-			$productId = $lineItemDetail['hdnProductId'.$key];
-			$entityType = $lineItemDetail['entityType'.$key];
-
+			$productId = isset($lineItemDetail['hdnProductId'.$key]) ? $lineItemDetail['hdnProductId'.$key] : "";
+			$entityType = isset($lineItemDetail['entityType'.$key]) ? $lineItemDetail['entityType'.$key] : "";
+			
 			//updating list price details
-			$productDetails[$key]['listPrice'.$key] = number_format((float)$convertedPriceDetails[$entityType][$productId], $numOfCurrencyDecimals, '.', '');
-
+			$productDetails[$key]['listPrice'.$key] = isset($convertedPriceDetails[$entityType][$productId]) ? number_format((float)$convertedPriceDetails[$entityType][$productId], $numOfCurrencyDecimals, '.', ''):"";			
 			//updating cost price details
-			$purchaseCost = (float)$userCurrencyInfo['conversion_rate'] * (float)$lineItemDetail['purchaseCost'.$key];
+			$purchaseCost = isset($lineItemDetail['purchaseCost'.$key]) ? (float)$userCurrencyInfo['conversion_rate'] * (float)$lineItemDetail['purchaseCost'.$key] :0;
 			$productDetails[$key]['purchaseCost'.$key] = number_format($purchaseCost, $numOfCurrencyDecimals, '.', '');
 
 			if($moduleName === 'PurchaseOrder') {
@@ -382,7 +381,7 @@ class Inventory_Record_Model extends Vtiger_Record_Model {
 			}
 
 			//Image detail
-			if ($imageDetailsList[$productId]) {
+			if (isset($imageDetailsList[$productId]) && $imageDetailsList[$productId]) {
 				$imageDetails = $imageDetailsList[$productId];
 				$productDetails[$key]['productImage'.$key] = $imageDetails[0]['path'].'_'.$imageDetails[0]['orgname'];
 			}
@@ -682,7 +681,7 @@ class Inventory_Record_Model extends Vtiger_Record_Model {
 		if ($chargeId) {
 			$chargeTaxModelsList = array();
 			$chargesAndItsTaxes = $this->getCharges();
-			$chargeInfo = $chargesAndItsTaxes[$chargeId];
+			$chargeInfo = isset($chargesAndItsTaxes[$chargeId]) ? $chargesAndItsTaxes[$chargeId] : "";
 			if ($chargeInfo && $chargeInfo['taxes']) {
 				$taxes = array_keys($chargeInfo['taxes']);
 				foreach ($taxes as $taxId) {
@@ -733,7 +732,7 @@ class Inventory_Record_Model extends Vtiger_Record_Model {
 
 			$subQtysList = array();
 			$subProducts = $requestData["subproduct_ids$i"];
-			$subProducts = split(',', rtrim($subProducts, ','));
+			$subProducts = explode(',', rtrim($subProducts, ','));
 
 			foreach ($subProducts as $subProductInfo) {
 				 list($subProductId, $subProductQty) = explode(':', $subProductInfo);
