@@ -63,7 +63,7 @@ class Users_Field_Model extends Vtiger_Field_Model {
 	 * @return <Boolean>
 	 */
 	public function isAjaxEditable() {
-		if(!$this->isEditable() || $this->get('uitype') == 105 || $this->get('uitype') == 106 || $this->get('uitype') == 98 || $this->get('uitype') == 101) {
+		if(!$this->isEditable() || $this->get('uitype') == 105 || $this->get('uitype') == 106 || $this->get('uitype') == 98 || $this->get('uitype') == 101 || ($this->get('uitype') == 21 && $this->getName() == 'signature')) {
 			return false;
 		}
 		return true;
