@@ -97,7 +97,7 @@ class Vtiger_Util_Helper {
 	 * @return <String>
 	 */
 	public static function pluralize($count, $text) {
-		return $count ." ". (($count == 1) ? vtranslate("$text") : vtranslate("${text}S"));
+		return $count ." ". (($count == 1) ? vtranslate("$text") : vtranslate("{$text}S"));
 	}
 
 	/**
@@ -105,7 +105,7 @@ class Vtiger_Util_Helper {
 	 */
 	public static function toSafeHTML($input) {
 		global $default_charset;
-		return htmlentities($input, ENT_QUOTES, $default_charset);
+		return $input ? htmlentities($input, ENT_QUOTES, $default_charset) : $input;
 	}
 
 	/**
@@ -115,7 +115,7 @@ class Vtiger_Util_Helper {
 	 */
 	public static function toVtiger6SafeHTML($input) {
 		$allowableTags = '<a><br>';
-		return strip_tags($input, $allowableTags);
+		return strip_tags((string) $input, $allowableTags);
 	}
 	/**
 	 * Function to validate the input with given pattern.
@@ -140,7 +140,7 @@ class Vtiger_Util_Helper {
 		global $adb;
 		$query = 'Select deleted from vtiger_crmentity where crmid=?';
 		$result = $adb->pquery($query, array($recordId));
-		return $adb->query_result($result, 'deleted');
+		return ($adb->num_rows($result) <= 0) ? 1 : (int) $adb->query_result($result, 0, 'deleted');
 	}
 
 	/**
@@ -182,7 +182,14 @@ class Vtiger_Util_Helper {
 			 */
 			if ($currentUser->get('date_format') === 'mm-dd-yyyy') {
 				$dateInUserFormat = str_replace('-', '/', $dateInUserFormat);
-			}
+			} else if ($currentUser->get('date_format') === 'dd/mm/yyyy'){
+				// strtotime expects m/d/y format - adjusting the format to make it friendly to its convention
+                $dateArray = explode('/', $dateInUserFormat);
+                $temp = $dateArray[0];
+                $dateArray[0] = $dateArray[1];
+                $dateArray[1] = $temp;
+                $dateInUserFormat = implode('/', $dateArray);
+            }
 
 			$date = strtotime($dateInUserFormat);
 			$formatedDate = vtranslate('LBL_'.date('D', $date)) . ' ' . date('d', $date) . ' ' . vtranslate('LBL_'.date('M', $date));
@@ -262,13 +269,17 @@ class Vtiger_Util_Helper {
 			$dateTimeInUserFormat = Vtiger_Datetime_UIType::getDisplayDateTimeValue($dateTime);
 		}
 
-		list($dateInUserFormat, $timeInUserFormat) = explode(' ', $dateTimeInUserFormat);
-		list($hours, $minutes, $seconds) = explode(':', $timeInUserFormat);
-
-		$displayTime = $hours .':'. $minutes;
-		if ($currentUser->get('hour_format') === '12') {
-			$displayTime = Vtiger_Time_UIType::getTimeValueInAMorPM($displayTime);
+		if (substr_count($dateTimeInUserFormat,' ') == 1) $dateTimeInUserFormat .= ' '; // init for meridiem if not present
+		list($dateInUserFormat, $timeInUserFormat, $meridiem) = explode(' ', $dateTimeInUserFormat);
+		if($meridiem && $currentUser->get('hour_format') === '12' ){
+			$displayTime = $timeInUserFormat.' '.$meridiem;
+		} else {
+			list($hours, $minutes, $seconds) = explode(':', $timeInUserFormat);
+			$displayTime = $hours .':'. $minutes;
+			if ($currentUser->get('hour_format') === '12') {
+				$displayTime = Vtiger_Time_UIType::getTimeValueInAMorPM($displayTime);
 		}
+	}
 
 		/**
 		 * To support strtotime() for 'mm-dd-yyyy' format the separator should be '/'
@@ -277,6 +288,13 @@ class Vtiger_Util_Helper {
 		 */
 		if ($currentUser->get('date_format') === 'mm-dd-yyyy') {
 			$dateInUserFormat = str_replace('-', '/', $dateInUserFormat);
+		} else if ($currentUser->get('date_format') === 'dd/mm/yyyy'){
+			// strtotime expects the format m/d/y making changes to its convenient
+			$dateArray = explode('/', $dateInUserFormat);
+			$temp = $dateArray[0];
+			$dateArray[0] = $dateArray[1];
+			$dateArray[1] = $temp;
+			$dateInUserFormat = implode('/', $dateArray);
 		}
 
 		$date = strtotime($dateInUserFormat);
@@ -1279,4 +1297,4 @@ class Vtiger_Util_Helper {
         }
         return $fieldValue;
     }
-}
\ No newline at end of file
+}
