@@ -1348,7 +1348,7 @@ class Vtiger_Field_Model extends Vtiger_Field {
 	}
 
 	public function hasDefaultValue() {
-		return !$this->defaultvalue || trim($this->defaultvalue) == '' ? false : true;
+		return isset($this->defaultvalue) && trim($this->defaultvalue) !== '';
 	}
 
 	public function isActiveField() {
