@@ -120,7 +120,12 @@ Vtiger_List_Js("MailManager_List_Js", {}, {
 			var element = jQuery(e.currentTarget);
 			var serverType = element.val();
 			var useServer = '', useProtocol = '', useSSLType = '', useCert = '';
-			if(serverType == 'gmail' || serverType == 'yahoo') {
+			if (serverType == 'google-oauth2') {
+				settingContainer.find('.settings_details').addClass('hide');
+				settingContainer.find('.additional_settings').addClass('hide');
+				settingContainer.find('.modal-footer').addClass('hide');
+				window.location.href = "oauth2callback/index.php?authfor=MailManager&authservice=Google";
+			} else if(serverType == 'gmail' || serverType == 'yahoo') {
 				useServer = 'imap.gmail.com';
 				if(serverType == 'yahoo') {
 					useServer = 'imap.mail.yahoo.com';
@@ -708,7 +713,14 @@ Vtiger_List_Js("MailManager_List_Js", {}, {
 				self.registerReplyAllEvent();
 				self.showRelatedActions();
 				self.registerMailPaginationEvent();
-				container.find('.emailDetails').popover({html: true});
+				let popoverEl = container.find('.emailDetails').popover({html: true});
+				/* enable allowed-tags in popover */
+				for (var tag of ["table", "tbody", "thead", "tr", "th", "td"]) {
+					if (!popoverEl.popover.Constructor.DEFAULTS.whiteList[tag]) {
+						popoverEl.popover.Constructor.DEFAULTS.whiteList[tag] = [];
+					}
+				}
+				
 				self.updateUnreadCount("-"+unreadCount, jQuery(parentEle).data('folder'));
 				self.loadContentsInIframe(container.find('#mmBody'));
 			});
